@@ -8,19 +8,19 @@ make_forecasts = function(x) {
 make_forecasts.calibration_simplex = function(x) {
   n = x$n
   n_bins = x$n_bins
-  forecasts = data.frame(p_a = rep(0,n_bins),p_b=rep(0,n_bins))
+  forecasts = data.frame(p1=rep(0,n_bins),p3 = rep(0,n_bins))
   k = n-2
-  pa = 0
-  pb = n-1
+  p3 = 0
+  p1 = n-1
   for(i in 1:n_bins) {
-    forecasts[i,] = c(pa,pb)
-    if(pb>0) {
-      pa=pa+1
-      pb=pb+-1
+    forecasts[i,] = c(p3,p1)
+    if(p1>0) {
+      p3=p3+1
+      p1=p1+-1
     }
     else {
-      pa=0
-      pb=k
+      p3=0
+      p1=k
       k=k-1
     }
   }
